@@ -32,6 +32,26 @@ def grep(filename, fragment, writeTo):
             fout.write(line)
 
 
+def readNums(filename):
+    """
+    Reads numbers from lines of a file, ignoring lines that can't be
+    converted to a float.
+    """
+    result = []
+    with open(filename, 'r') as fin:
+        nextLine = fin.readline()
+        while nextLine:
+            try:
+                val = float(nextLine.strip())
+            except Exception:
+                val = None
+            if val is not None:
+                result.append(val)
+            nextLine = fin.readline()
+
+    return result
+
+
 def addRecords(filename, records):
     """
     Given a filename and a list of strings, adds one line to the file
