@@ -35,8 +35,8 @@ def printMessage(message, width):
 
 
 m = opt.testFunction(printMessage)
-m.case('hi', 4).checkOutputLines('  hi')
-m.case('hello', 4).checkOutputLines('hello')
+m.case('hi', 4).checkPrintedLines('  hi')
+m.case('hello', 4).checkPrintedLines('hello')
 
 
 import math # noqa
@@ -52,8 +52,8 @@ def ellipseArea(radius1, radius2):
 
 
 m = opt.testFunction(ellipseArea)
-m.case(1, 1).checkResult(math.pi)
-m.case(2, 3).checkResult(6 * math.pi)
+m.case(1, 1).checkReturnValue(math.pi)
+m.case(2, 3).checkReturnValue(6 * math.pi)
 
 
 from turtle import * # noqa
