@@ -205,7 +205,13 @@ from potluck import meta # noqa E402
 
 meta.example("imperfect")
 
-meta.expect_warnings('invalid syntax (debugMe.py, line 13)')
+import sys # noqa E402
+if sys.version_info < (3, 10):
+    meta.expect_warnings('invalid syntax (debugMe.py, line 13)')
+else:
+    meta.expect_warnings(
+        'invalid syntax. Perhaps you forgot a comma? (debugMe.py, line 13)'
+    )
 
 for bug_nr in [1, 2, 3, 5, 11]:
     meta.expect(
