@@ -167,8 +167,8 @@ meta.expect("accomplished", "procedure", "core", "define printMessage",
 meta.expect("failed", "procedure", "core", "define printMessage",
             "call indentMessage")
 # A few using IDs instead of rubric paths
-meta.expect("failed", "#def-polygon$")
-meta.expect("failed", "#def-polygon:loop$")
+meta.expect("partial", "#def-polygon$")
+meta.expect("partial", "#def-polygon:loop$")
 meta.expect("failed", "#def-polygon:loop:call-")
 
 # specifying as rubric paths:
